@@ -23,6 +23,7 @@
 #include "o2_germany.hpp"
 #include "../providerplugin.hpp"
 #include "../accountsettingsdialog.hpp"
+#include "../util.hpp"
 
 // Global includes
 #include <QtCore/QRegExp>
@@ -514,7 +515,7 @@ void o2Germany::sendMessage(const Message& message)
 
   // Fill the remaining fields
   d->sendFormDefaultValues.insert("SMSTo", smsTo.toAscii().toPercentEncoding());
-  d->sendFormDefaultValues.insert("SMSText", message.text().toAscii().toPercentEncoding());
+  d->sendFormDefaultValues.insert("SMSText", toUrlPercentEncoding(message.text().toLocal8Bit()));
 
   // Fill the default values
   QHashIterator<QString, QByteArray> iter(d->sendFormDefaultValues);
